django-simple-history
=====================

.. image:: https://secure.travis-ci.org/treyhunner/django-simple-history.png?branch=master
   :target: http://travis-ci.org/treyhunner/django-simple-history
.. image:: https://coveralls.io/repos/treyhunner/django-simple-history/badge.png?branch=master
   :target: https://coveralls.io/r/treyhunner/django-simple-history
.. image:: https://pypip.in/v/django-simple-history/badge.png
   :target: https://crate.io/packages/django-simple-history
.. image:: https://pypip.in/d/django-simple-history/badge.png
   :target: https://crate.io/packages/django-simple-history

django-simple-history stores Django model state on every create/update/delete.

This app requires Django 1.4.13 or greater and Python 2.6 or greater.

Getting Help
------------

Documentation is available at https://django-simple-history.readthedocs.org/

Issue tracker is at https://github.com/treyhunner/django-simple-history/issues

Pull requests are welcome.  Read the CONTRIBUTING file for tips on
submitting a pull request.

.. _PyPI: https://pypi.python.org/pypi/django-email-log/


.. image:: https://d2weczhvl823v0.cloudfront.net/treyhunner/django-simple-history/trend.png
   :alt: Bitdeli badge
   :target: https://bitdeli.com/free

